==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lxqt-panel/plugin-directorymenu/directorymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../../directorymenu.cpp" line="120"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Paramètrage du menu des répertoires</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Répertoire de base :</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Nom du répertoire de base</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.cpp" line="92"/>
        <source>Choose Base Directory</source>
        <translation>Choisir le répertoire de base</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.cpp" line="108"/>
        <source>Choose Icon</source>
        <translation>Choisir l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.cpp" line="108"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Icônes (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.cpp" line="117"/>
        <source>Directory Menu</source>
        <translation>Menu des répertoires</translation>
    </message>
    <message>
        <location filename="../../directorymenuconfiguration.cpp" line="117"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Echec du chargement de l&apos;icône.</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-directorymenu/directorymenu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../../../directorymenu.cpp" line="121"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Paramètrage du menu des répertoires</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Répertoire de base :</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>Nom du répertoire de base</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icône :</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="92"/>
        <source>Choose Base Directory</source>
        <translation>Choisir le répertoire de base</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="108"/>
        <source>Choose Icon</source>
        <translation>Choisir l&apos;icône</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="108"/>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Icônes (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="117"/>
        <source>Directory Menu</source>
        <translation>Menu des répertoires</translation>
    </message>
    <message>
        <location filename="../../../directorymenuconfiguration.cpp" line="117"/>
        <source>An error occurred while loading the icon.</source>
        <translation>Echec du chargement de l&apos;icône.</translation>
    </message>
</context>
</TS>
